Kadal
=====

Kadal is an async wrapper for the `Anilist <https://anilist.co/>`_ API.

This wrapper is compatible with Python 3.5+.
Kadal is compatible with python's standard `asyncio <https://docs.python.org/3/library/asyncio.html>`_ or `trio <https://github.com/python-trio/trio>`_ / `curio <https://github.com/dabeaz/curio>`_ through `multio <https://github.com/theelous3/multio>`_.

Documentation to be added soon.

This wrapper is aimed at ease of use and an object-oriented style, and stays as true as possible to the `anilist API v2 <https://github.com/AniList/ApiV2-GraphQL-Docs>`_.

Installation
------------

Kadal is available through pip:
::

    pip install -U kadal


Example
-------
To be added soon.